@@ -1,12 +1,5 @@
-import django.core.exceptions
-
 from django.conf import settings
 
-try:
-    getattr(settings, '')
-except django.core.exceptions.ImproperlyConfigured:
-    settings = {}
-
 REDIS = {
     'password': '',
     'port': 6379,
@@ -18,3 +11,10 @@ if hasattr(settings, 'REDIS'):
 HOME_URL = getattr(settings, 'HOME_URL', '/')
 PRIMARY_USER_MODEL = getattr(settings, 'PRIMARY_USER_MODEL', 'app.User')
 
+try:
+    from redis import Redis
+except ImportError:
+    REDIS_AVAILABLE = False
+else:
+    REDIS_AVAILABLE = True
+
