@@ -6,7 +6,6 @@ import string
 import time
 import unicodedata
 
-import django.core.exceptions
 from django.http import HttpResponse
 from django.utils.functional import lazy
 from django.core.urlresolvers import reverse
@@ -17,10 +16,7 @@ except ImportError:
     # Django 1.6+
     from django.conf.urls import url
 
-try:
-    from django.views.generic.base import TemplateView
-except django.core.exceptions.ImproperlyConfigured:
-    pass
+from django.views.generic.base import TemplateView
 
 class JSONResponse(HttpResponse):
     def __init__(self, content, content_type='application/json', *args, **kwargs):
